pub struct BGTaskScheduler { /* private fields */ }BGTaskScheduler only.Expand description
A class for scheduling task requests that launch your app in the background.
Background tasks give your app a way to run code while the app is suspended. To learn how to register, schedule, and run a background task, see <doc ://com.apple.documentation/documentation/uikit/app_and_environment/scenes/preparing_your_ui_to_run_in_the_background/using_background_tasks_to_update_your_app>.
See also Apple’s documentation
Implementations
Sourceimpl BGTaskScheduler
impl BGTaskScheduler
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
The shared background task scheduler instance.
Sourcepub unsafe fn supportedResources() -> BGContinuedProcessingTaskRequestResources
Available on crate feature BGTaskRequest only.
pub unsafe fn supportedResources() -> BGContinuedProcessingTaskRequestResources
BGTaskRequest only.A bitfield of the resources the device supports for BackgroundTasks/BGContinuedProcessingTaskRequest instances.
Sourcepub unsafe fn registerForTaskWithIdentifier_usingQueue_launchHandler(
&self,
identifier: &NSString,
queue: Option<&DispatchQueue>,
launch_handler: &DynBlock<dyn Fn(NonNull<BGTask>)>,
) -> bool
Available on crate features BGTask and block2 and dispatch2 only.
pub unsafe fn registerForTaskWithIdentifier_usingQueue_launchHandler( &self, identifier: &NSString, queue: Option<&DispatchQueue>, launch_handler: &DynBlock<dyn Fn(NonNull<BGTask>)>, ) -> bool
BGTask and block2 and dispatch2 only.Register a launch handler for the task with the associated identifier that’s executed on the specified queue.
Every identifier in the <doc ://com.apple.documentation/documentation/bundleresources/information_property_list/bgtaskschedulerpermittedidentifiers> requires a handler. Registration of all launch handlers must be complete before the end of <doc ://com.apple.documentation/documentation/uikit/uiapplicationdelegate/1623053-applicationdidfinishlaunching>.
You must register launch handlers before your application finishes launching (BGContinuedProcessingTask
registrations are exempt from this requirement). Attempting to register a handler after launch or multiple handlers
for the same identifier is an error. Although you may submit task requests from some extensions, only the host app
will be launched to handle background work.
- Parameters:
- identifier: The identifier for the task that will be handled by the provided launch handler.
- queue: A queue for executing the task. Pass
nilto use a default background queue. - launchHandler: The system runs the block of code for the launch handler when it launches the app in the background. The block takes a single parameter, a
BGTaskobject used for assigning an expiration handler and for setting a completion status. The block has no return value. Assign an expiration handler to the task’s expirationHandler property and call setTaskCompletedWithSuccess: when the background work is complete. - Returns: Returns
<doc
://com.apple.documentation/documentation/objectivec/yes> if the launch handler was registered. Returns
<doc
://com.apple.documentation/documentation/objectivec/no> if the identifier isn’t included in the
<doc
://com.apple.documentation/documentation/bundleresources/information_property_list/bgtaskschedulerpermittedidentifiers>
Info.plist. - Important: Register each task identifier only once. The system kills the app on the second registration of the same task identifier.
Safety
queue possibly has additional threading requirements.
Sourcepub unsafe fn submitTaskRequest_error(
&self,
task_request: &BGTaskRequest,
) -> Result<(), Retained<NSError>>
Available on crate feature BGTaskRequest only.
pub unsafe fn submitTaskRequest_error( &self, task_request: &BGTaskRequest, ) -> Result<(), Retained<NSError>>
BGTaskRequest only.Submit a previously registered background task for execution.
Submitting a task request for an unexecuted task that’s already in the queue replaces the previous task request.
There can be a total of 1 refresh task and 10 processing tasks scheduled at any time. Trying to schedule more tasks
returns BGTaskSchedulerErrorCode/BGTaskSchedulerErrorCodeTooManyPendingTaskRequests.
- Parameters:
- taskRequest: The task request object representing the parameters of the background task to be scheduled.
- error: If an error occurs, upon return contains an error object that indicates why the request was rejected
- Returns:
YESif the request was successfully submitted;NOif there was an error
Sourcepub unsafe fn cancelTaskRequestWithIdentifier(&self, identifier: &NSString)
pub unsafe fn cancelTaskRequestWithIdentifier(&self, identifier: &NSString)
Cancel a previously scheduled task request.
- Parameters:
- identifier: The identifier of the previously submitted task request to cancel.
Sourcepub unsafe fn cancelAllTaskRequests(&self)
pub unsafe fn cancelAllTaskRequests(&self)
Cancel all previously submitted task requests.
Sourcepub unsafe fn getPendingTaskRequestsWithCompletionHandler(
&self,
completion_handler: &DynBlock<dyn Fn(NonNull<NSArray<BGTaskRequest>>)>,
)
Available on crate features BGTaskRequest and block2 only.
pub unsafe fn getPendingTaskRequestsWithCompletionHandler( &self, completion_handler: &DynBlock<dyn Fn(NonNull<NSArray<BGTaskRequest>>)>, )
BGTaskRequest and block2 only.Returns a list of all task requests that have been submitted but not yet completed.
The handler takes a single parameter tasksRequests, an array of BGTaskRequest
objects. The array is empty if there are no scheduled tasks.
The objects passed in the array are copies of the existing requests. Changing the attributes of a request has no
effect. To change the attributes submit a new task request using BGTaskScheduler/submitTaskRequest:error:.
- Parameters:
- completionHandler: The completion handler called with the pending tasks.
- Note: The handler may execute on a background thread.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for BGTaskScheduler
impl AsRef<AnyObject> for BGTaskScheduler
Sourceimpl AsRef<BGTaskScheduler> for BGTaskScheduler
impl AsRef<BGTaskScheduler> for BGTaskScheduler
Sourceimpl AsRef<NSObject> for BGTaskScheduler
impl AsRef<NSObject> for BGTaskScheduler
Sourceimpl Borrow<AnyObject> for BGTaskScheduler
impl Borrow<AnyObject> for BGTaskScheduler
Sourceimpl Borrow<NSObject> for BGTaskScheduler
impl Borrow<NSObject> for BGTaskScheduler
Sourceimpl ClassType for BGTaskScheduler
impl ClassType for BGTaskScheduler
Sourceconst NAME: &'static str = "BGTaskScheduler"
const NAME: &'static str = "BGTaskScheduler"
Sourcetype ThreadKind = <<BGTaskScheduler as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<BGTaskScheduler as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for BGTaskScheduler
impl Debug for BGTaskScheduler
Sourceimpl Deref for BGTaskScheduler
impl Deref for BGTaskScheduler
Sourceimpl Hash for BGTaskScheduler
impl Hash for BGTaskScheduler
Sourceimpl Message for BGTaskScheduler
impl Message for BGTaskScheduler
Sourceimpl NSObjectProtocol for BGTaskScheduler
impl NSObjectProtocol for BGTaskScheduler
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref